#[non_exhaustive]pub enum DefinedType {
Show 28 variants
Figure,
Dataset,
Media,
Poster,
JournalContribution,
Presentation,
Thesis,
Software,
OnlineResource,
Preprint,
Book,
ConferenceContribution,
Chapter,
PeerReview,
EducationalResource,
Report,
Standard,
Composition,
Funding,
PhysicalObject,
DataManagementPlan,
Workflow,
Monograph,
Performance,
Event,
Service,
Model,
Unknown(String),
}Expand description
Typed article kind used by Figshare payloads and search filters.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Figure
Figure.
Dataset
Dataset.
Media
Media.
Poster
Poster.
JournalContribution
Journal contribution.
Presentation
Presentation.
Thesis
Thesis.
Software
Software.
OnlineResource
Online resource.
Preprint
Preprint.
Book
Book.
ConferenceContribution
Conference contribution.
Chapter
Chapter.
PeerReview
Peer review.
EducationalResource
Educational resource.
Report
Report.
Standard
Standard.
Composition
Composition.
Funding
Funding.
PhysicalObject
Physical object.
DataManagementPlan
Data management plan.
Workflow
Workflow.
Monograph
Monograph.
Performance
Performance.
Event
Event.
Service
Service.
Model
Model.
Unknown(String)
Unknown server value preserved as-is.
Implementations
Sourceimpl DefinedType
impl DefinedType
Sourcepub fn api_name(&self) -> &str
pub fn api_name(&self) -> &str
Returns the string form used by create and update payloads.
Examples
use figshare_rs::DefinedType;
assert_eq!(DefinedType::Software.api_name(), "software");
assert_eq!(
DefinedType::JournalContribution.api_name(),
"journal contribution"
);Sourcepub fn api_id(&self) -> Option<u64>
pub fn api_id(&self) -> Option<u64>
Returns the numeric form used by some list/search filters and presenters.
Sourcepub fn from_api_id(id: u64) -> Self
pub fn from_api_id(id: u64) -> Self
Converts the integer representation used by presenter payloads into a
typed DefinedType.
Sourcepub fn from_api_name(value: impl Into<String>) -> Self
pub fn from_api_name(value: impl Into<String>) -> Self
Converts the string representation used by create/update payloads into a
typed DefinedType.